(********************************************************************
 * COPYRIGHT --  
 ********************************************************************
 * Package: MultiAxis
 * File: GlobalMultiAxis.typ
 * Author: zhh
 * Created: September 01, 2016
 ********************************************************************
 * Data types of package MultiAxis
 ********************************************************************)
(**Structure to define servo command*)

TYPE
	multiAxisCmd_typ : 	STRUCT 
		ctrlOn : BOOL;
		ctrlOff : BOOL;
		absMove : BOOL;
		relMove : BOOL;
		posMove : BOOL;
		negMove : BOOL;
		home : BOOL;
		stop : BOOL;
		triggerStop : BOOL;
		camStart : BOOL;
		errorAcknowledge : BOOL;
	END_STRUCT;
END_TYPE

(**Structure for controller parameter*)

TYPE
	multiAxisPara_typ : 	STRUCT 
		velocity : DINT; (*Units/s*)
		acceleration : DINT; (*Units/s^2*)
		deceleration : DINT; (*Units/s^2*)
		stopDeceleration : DINT; (*Units/s^2*)
		relPosition : DINT; (*Units*)
		absPosition : DINT; (*Units*)
		homeMode : DINT;
		homePosition : DINT;
		homeSpeed : DINT;
		homeAcce : DINT;
		trigStopOffset : DINT;
	END_STRUCT;
END_TYPE

(**Structure for monitor servo status*)

TYPE
	multiAxisStatus_typ : 	STRUCT 
		actVelocity : DINT;
		actPosition : DINT;
		inPosition : USINT;
		homeReady : USINT;
		ctrlReady : USINT;
		moveMode : UINT;
		triggerStopReady : USINT;
		step : UINT;
		errorStep : UINT;
	END_STRUCT;
END_TYPE

(**Structure for error*)

TYPE
	multiAxisAlarm_typ : 	STRUCT 
		errorNumber : UINT; (*Error message(english)*)
		errorText : ARRAY[0..3]OF STRING[79]; (*Error message(english)*)
	END_STRUCT;
END_TYPE

(**Servo axis control structure*)

TYPE
	multiAxis_typ : 	STRUCT 
		cmd : multiAxisCmd_typ;
		para : multiAxisPara_typ;
		status : multiAxisStatus_typ;
		alarm : multiAxisAlarm_typ;
	END_STRUCT;
END_TYPE

(*Vaxis structure*)

TYPE
	multiVAxisCmd_typ : 	STRUCT 
		absMove : BOOL;
		relMove : BOOL;
		posMove : BOOL;
		negMove : BOOL;
		home : BOOL;
		stop : BOOL;
		camStart : BOOL;
		errorAcknowledge : BOOL;
	END_STRUCT;
	multiVAxisPara_typ : 	STRUCT 
		velocity : DINT; (*Units/s*)
		acceleration : DINT; (*Units/s*)
		deceleration : DINT; (*Units/s*)
		stopDeceleration : DINT; (*Units/s^2*)
		relPosition : DINT; (*Units*)
		absPosition : DINT; (*Units*)
		homeMode : DINT;
		homePosition : DINT;
	END_STRUCT;
	multiVAxisStatus_typ : 	STRUCT 
		actVelocity : DINT;
		actPosition : DINT;
		inPosition : USINT;
		homeReady : USINT;
		ctrlReady : USINT;
		moveMode : UINT;
		step : UINT;
		errorStep : UINT;
	END_STRUCT;
	multiVAxisAlarm_typ : 	STRUCT 
		errorNumber : UINT; (*Error message(english)*)
		errorText : ARRAY[0..3]OF STRING[79]; (*Error message(english)*)
	END_STRUCT;
	multiVAxis_typ : 	STRUCT 
		cmd : multiVAxisCmd_typ;
		para : multiVAxisPara_typ;
		status : multiVAxisStatus_typ;
		alarm : multiVAxisAlarm_typ;
	END_STRUCT;
END_TYPE
